@@ -1,19 +1,26 @@
 from honkaiDex.__config__ import _gconfig, _cconfig, has_gconfig
 
 class gconfig(_gconfig):
-    STIGAMATA = "stigamata_1"
+    MIN_LV = 1
+    MAX_LV = 88
 
-class config(_cconfig):
+    STIGAMATA = "stigamata_1"
+    CHARACTER = "character_0"
+class config(_cconfig):    
     class data(_cconfig):
         class stigamata_1(_cconfig):
             FILENAME = "stigamata_1.json"
 
+        class character_0(_cconfig):
+            FILENAME = "character_0.json"
+
     class profile(_cconfig):
         class cached(_cconfig):
             STIGAMATA = gconfig
-
+            CHARACTER = gconfig
         class just_stigamata(_cconfig):
             STIGAMATA = gconfig
 
-    
+        class just_character(_cconfig):
+            CHARACTER = gconfig
             
\ No newline at end of file
